"""
Command to load fixtures for Resume Manager Core models.
"""

# Third-Party Imports.
from django.contrib.auth import get_user_model
from django.core.management import call_command
from django.core.management.base import BaseCommand

# Internal Imports.
from apps.Resume_Manager.resume_manager_core.models import (
    Resume,
    ResumeTheme,
    ResumeSection,
    ResumeToSectionIntermediary,
    DataSectionHeader,
    DataItem,
)
from workspace_core.settings.reusable_settings import ConsoleColors


class Command(BaseCommand):
    help = 'Load fixtures into database models for Resume Manager Core app.'

    def handle(self, *args, **kwargs):
        """
        The logic of the command.
        """
        print('{0}RESUME_MANAGER_CORE{1}: {2}Load Fixtures{3} command has been called.'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

        # Run fixture imports.
        self.populate_resume_sections()
        self.populate_resume_themes()
        self.populate_resumes()
        self.populate_resume_section_intermediaries()
        self.populate_data_section_headers()
        self.populate_data_section_items()

        print('{0}RESUME_MANAGER_CORE{1}: {2}Fixture Loading{3} complete.\n'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

    def populate_resume_sections(self):
        """
        Loads fixtures for ResumeSection models.
        """
        call_command('loaddata', 'resume_manager/resume_sections.json')

    def populate_resume_themes(self):
        """
        Loads fixtures for ResumeTheme models.
        """
        call_command('loaddata', 'resume_manager/resume_themes.json')

    def populate_resumes(self):
        """
        Loads fixtures for Resume models.
        """
        # No fixtures yet.
        pass

    def populate_resume_section_intermediaries(self):
        """
        Loads fixtures for ResumeToSectionIntermediary models.
        """

        # Get "example_user" to associate all example resumes with.
        example_user = get_user_model().objects.get(username='example_user')

        # Create an example resume for each theme.
        resume_themes = ResumeTheme.objects.filter(name__startswith='Blocky ')
        for resume_theme in resume_themes:

            # Create new example resume for theme.
            current_resume = Resume.objects.create(
                user=example_user,
                theme=resume_theme,
                name='Example {0} Resume'.format(resume_theme.name),
            )

            # Get resume section models.
            section_format_page = ResumeSection.objects.get(name='Page')
            section_format_row_full = ResumeSection.objects.get(name='Row: Full')
            section_format_column_full = ResumeSection.objects.get(name='Column: Full')
            section_format_text_left = ResumeSection.objects.get(name='Text: Left-Align')
            section_format_text_center = ResumeSection.objects.get(name='Text: Center-Align')
            section_format_text_right = ResumeSection.objects.get(name='Text: Right-Align')
            section_format_style_full = ResumeSection.objects.get(name='Style: Full Color')

            # For each resume, create 4 pages to showcase different possible formats.
            page_1 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format_page,
            )
            page_2 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format_page,
            )
            page_3 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format_page,
            )
            page_4 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format_page,
            )

            # Create page 1 main subsections.
            # Page one is in standard <header, middle, footer> format.
            page_1_header = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format_row_full,
            )
            page_1_header_background = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header,
                section_format=section_format_style_full,
            )
            page_1_header_left = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_background,
                section_format=section_format_row_full,
            )
            page_1_header_name = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_left,
                section_format=section_format_text_left,
            )
            page_1_header_right = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_background,
                section_format=section_format_column_full,
            )
            page_1_header_profession = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_right,
                section_format=section_format_text_center,
            )
            page_1_middle = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format_column_full,
            )
            page_1_footer = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format_row_full,
            )
            page_1_footer_background = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_footer,
                section_format=section_format_style_full,
            )

            # Create page 2 main subsections.
            # Mimics a full resume in single-page format.

    def populate_data_section_headers(self):
        """
        Loads fixtures for DataSectionHeader models.
        """
        # No fixtures yet.
        pass

    def populate_data_section_items(self):
        """
        Loads fixtures for DataSectionItem models.
        """
        # No fixtures yet.
        pass
