"""
Command to create seeds for ResumeManager app models.
"""

# Third-Party Imports.
from django.core.management.base import BaseCommand

# Internal Imports.
from . import resume_manager_core__loadfixtures
from workspace_core.settings.reusable_settings import ConsoleColors


# Initialize fixture class.
app_fixtures = resume_manager_core__loadfixtures.Command()


class Command(BaseCommand):
    help = 'Seed database models with randomized data for ResumeManager app.'

    def add_arguments(self, parser):
        """
        Parser for command.
        """
        # Optional arguments.
        parser.add_argument(
            'model_count',
            type=int,
            nargs='?',
            default=100,
            help='Number of randomized models to create. Defaults to 100. Cannot exceed 10,000.',
        )

    def handle(self, *args, **kwargs):
        """
        The logic of the command.
        """
        # Limit range of model_count variable.
        model_count = kwargs['model_count']
        if model_count < 1:
            model_count = 100
        elif model_count > 10000:
            model_count = 100

        print('{0}RESUME_MANAGER{1}: {2}Seed{3} command has been called.'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

        # Run fixture imports.
        self.create_resume_sections(model_count)
        self.create_resume_themes(model_count)
        self.create_resumes(model_count)
        self.create_resume_section_intermediaries(model_count)
        self.create_data_section_headers(model_count)
        self.create_data_section_items(model_count)

        print('{0}RESUME_MANAGER{1}: {2}Seeding{3} complete.\n'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

    def create_resume_sections(self, model_count):
        """
        Create seeds for ResumeSection models.
        """
        # Load preset fixtures.
        app_fixtures.populate_resume_sections()

        # Seed logic goes here.

    def create_resume_themes(self, model_count):
        """
        Create seeds for ResumeTheme models.
        """
        # Load preset fixtures.
        app_fixtures.populate_resume_themes()

        # Seed logic goes here.

    def create_resumes(self, model_count):
        """
        Create seeds for Resume models.
        """
        # Load preset fixtures.
        app_fixtures.populate_resumes()

        # Seed logic goes here.

    def create_resume_section_intermediaries(self, model_count):
        """
        Create seeds for ResumeToSectionIntermediary models.
        """
        # Load preset fixtures.
        app_fixtures.populate_resume_section_intermediaries()

        # Seed logic goes here.

    def create_data_section_headers(self, model_count):
        """
        Create seeds for DataSectionHeader models.
        """
        # Load preset fixtures.
        app_fixtures.populate_data_section_headers()

        # Seed logic goes here.

    def create_data_section_items(self, model_count):
        """
        Create seeds for DataSectionItem models.
        """
        # Load preset fixtures.
        app_fixtures.populate_data_section_items()

        # Seed logic goes here.
